import { ManifestEndpoint } from '../runtime/manifest';
/**
 * A CloudEventBase is the base of a cross-platform format for encoding a serverless event.
 * More information can be found in https://github.com/cloudevents/spec
 */
export interface CloudEvent<T> {
    /** Version of the CloudEvents spec for this event. */
    readonly specversion: '1.0';
    /** A globally unique ID for this event. */
    id: string;
    /** The resource which published this event. */
    source: string;
    /** The resource, provided by source, that this event relates to */
    subject?: string;
    /** The type of event that this represents. */
    type: string;
    /** When this event occurred. */
    time: string;
    /** Information about this specific event. */
    data: T;
}
/** A handler for CloudEvents. */
export interface CloudFunction<EventType extends CloudEvent<unknown>> {
    (raw: CloudEvent<unknown>): any | Promise<any>;
    __trigger?: unknown;
    __endpoint: ManifestEndpoint;
    run(event: EventType): any | Promise<any>;
}
